@@ -1,10 +1,10 @@
-from __future__ import annotations
 import os
 from copy import copy
 import struct
 from enum import Enum, IntEnum
 from warnings import warn
 import tempfile
+from random import Random
 from collections import Counter
 import typing as ty
 import shutil
@@ -35,7 +35,7 @@ from .exceptions import (
     FileFormatsExtrasPkgNotCheckedError,
 )
 from .datatype import DataType
-from . import mark
+from . import hook
 
 try:
     from typing import Self
@@ -49,7 +49,7 @@ FILE_CHUNK_LEN_DEFAULT = 8192
 logger = logging.getLogger("fileformats")
 
 
-@attrs.define(slots=False, repr=False)
+@attrs.define(repr=False)
 class FileSet(DataType):
     """
     The base class for all format types within the fileformats package. A generic
@@ -61,11 +61,24 @@ class FileSet(DataType):
     ----------
     fspaths : set[Path]
         a set of file-system paths pointing to all the resources in the file-set
-    checks : bool
-        whether to run in-depth "checks" to verify the file format
+    metadata : dict[str, Any]
+        metadata associated with the file-set, typically lazily loaded via `read_metadata`
+        extras hook
     """
 
     fspaths: ty.FrozenSet[Path] = attrs.field(default=None, converter=fspaths_converter)
+    _metadata: ty.Optional[ty.Dict[str, ty.Any]] = attrs.field(
+        default=False,
+        eq=False,
+        order=False,
+    )
+
+    @_metadata.validator
+    def metadata_validator(self, _, val):
+        if val and not isinstance(val, dict):
+            raise TypeError(
+                f"Fileset metadata value needs to be None or dict, not {val} ({self.fspaths})"
+            )
 
     # Explicitly set the Internet Assigned Numbers Authority (https://iana_mime.org) MIME
     # type to None for any base classes that should not correspond to a MIME or MIME-like
@@ -173,34 +186,66 @@ class FileSet(DataType):
             pass
         return possible
 
-    @functools.cached_property
+    @property
     def metadata(self) -> ty.Dict[str, ty.Any]:
         """Lazily load metadata from `read_metadata` extra if implemented, returning an
         empty metadata array if not"""
+        if self._metadata is not False:
+            return self._metadata
         try:
-            metadata = self.read_metadata()
+            self._metadata = self.read_metadata()
         except FileFormatsExtrasPkgUninstalledError:
             raise
         except FileFormatsExtrasPkgNotCheckedError as e:
             logger.warning(str(e))
-            metadata = None
+            self._metadata = None
         except FileFormatsExtrasError:
-            metadata = None
-        return metadata
+            self._metadata = None
+        return self._metadata
 
-    @mark.extra
-    def read_metadata(self) -> ty.Dict[str, ty.Any]:
-        """Reads any metadata associated with the fileset and returns it as a dict"""
+    def select_metadata(self, selected_keys: ty.Union[ty.Sequence[str], None]):
+        """Selects a subset of the metadata to be read and stored instead all available
+        (i.e for performance reasons).
+
+        Parameters
+        ----------
+        selected_keys : Union[Sequence[str], None]
+            the keys of the values to load. If None, all values are loaded
+        """
+        if (
+            self._metadata
+            and selected_keys is not None
+            and set(selected_keys).issubset(self._metadata)
+        ):
+            return
+        self._metadata = self.read_metadata(selected_keys)
+
+    @hook.extra
+    def read_metadata(
+        self, selected_keys: ty.Optional[ty.Sequence[str]] = None
+    ) -> ty.Mapping[str, ty.Any]:
+        """Reads any metadata associated with the fileset and returns it as a dict
+
+        Parameters
+        ----------
+        selected_keys : Sequence[str], optional
+            selected keys to load instead of loading the complete metadata set
+
+        Returns
+        -------
+        metadata : Mapping[str, Any]
+            a mapping from names of the metadata fields to their values
+        """
         raise NotImplementedError
 
     @classmethod
-    def required_properties(cls):
+    def required_properties(cls) -> ty.Generator[str, None, None]:
         """Find all properties required to treat file-set as being in the format specified
         by the class
 
         Returns
         -------
-        iter(str)
+        Generator[str, None, None]
             an iterator over all properties names marked as "required"
         """
         fileset_props = dir(FileSet)
@@ -235,7 +280,7 @@ class FileSet(DataType):
                     required.add(path)
         return required
 
-    def nested_filesets(self) -> ty.List[FileSet]:
+    def nested_filesets(self) -> ty.List["FileSet"]:
         """Returns all nested filesets that are required for the format
 
         Returns
@@ -518,7 +563,7 @@ class FileSet(DataType):
         converter_tuple: ty.Tuple[ty.Callable, ty.Dict[str, ty.Any]],
     ):
         """Registers a converter task within a class attribute. Called by the
-        @fileformats.mark.converter decorator.
+        @fileformats.hook.converter decorator.
 
         Parameters
         ----------
@@ -609,7 +654,7 @@ class FileSet(DataType):
         relative_to: ty.Optional[os.PathLike] = None,
         ignore_hidden_files: bool = False,
         ignore_hidden_dirs: bool = False,
-    ) -> ty.Generator[str, ty.Generator[bytes]]:
+    ) -> ty.Generator[ty.Tuple[str, bytes], None, None]:
         """Yields relative paths for all files within the file-set along with iterators
         over their byte-contents. To be used when generating hashes for the file set.
 
@@ -844,7 +889,7 @@ class FileSet(DataType):
         if not dest_dir:
             dest_dir = Path(tempfile.mkdtemp())
         # Need to use mock to get an instance in order to use the singledispatch-based
-        # mark.extra decorator
+        # hook.extra decorator
         mock = cls.mock()
         fspaths = mock.generate_sample_data(dest_dir, seed, stem)
         try:
@@ -857,9 +902,12 @@ class FileSet(DataType):
             )
         return obj
 
-    @mark.extra
+    @hook.extra
     def generate_sample_data(
-        self, dest_dir: Path, seed: int = 0, stem: str = None
+        self,
+        dest_dir: Path,
+        seed: ty.Union[int, Random] = 0,
+        stem: ty.Optional[str] = None,
     ) -> ty.Iterable[Path]:
         """Generate test data at the fspaths of the file-set
 
