@@ -10,7 +10,7 @@ from fileformats.core.exceptions import (
     FormatMismatchError,
     UnconstrainedExtensionException,
 )
-from fileformats.core import mark
+from fileformats.core import hook
 from fileformats.core.utils import classproperty, gen_filename
 from fileformats.core.mixin import WithClassifiers
 
@@ -18,7 +18,7 @@ from fileformats.core.mixin import WithClassifiers
 class FsObject(FileSet, os.PathLike):
     "Generic file-system object, can be either a file or a directory"
 
-    @mark.required
+    @hook.required
     @property
     def fspath(self):
         if len(self.fspaths) > 1:
@@ -55,7 +55,7 @@ class File(FsObject):
     binary = True
     is_dir = False
 
-    @mark.required
+    @hook.required
     @property
     def fspath(self):
         fspath = self.select_by_ext()
@@ -154,7 +154,7 @@ class Directory(FsObject):
 
     content_types = ()
 
-    @mark.required
+    @hook.required
     @property
     def fspath(self):
         # fspaths are checked for existence with the exception of mock classes
@@ -200,7 +200,7 @@ class Directory(FsObject):
         constraint"""
         return super().unconstrained and not cls.content_types
 
-    @mark.check
+    @hook.check
     def validate_contents(self):
         if not self.content_types:
             return
@@ -238,7 +238,7 @@ class TypedSet(FileSet):
                 except FormatMismatchError:
                     continue
 
-    @mark.check
+    @hook.check
     def validate_contents(self):
         if not self.content_types:
             return
@@ -278,8 +278,11 @@ FILE_LENGTH = 1000
 
 @FileSet.generate_sample_data.register
 def fsobject_generate_sample_data(
-    fsobject: FsObject, dest_dir: Path, seed: int, stem: ty.Optional[str]
-) -> ty.List[Path]:
+    fsobject: FsObject,
+    dest_dir: Path,
+    seed: ty.Union[int, Random] = 0,
+    stem: ty.Optional[str] = None,
+) -> ty.Iterable[Path]:
     a_file = dest_dir / gen_filename(seed, file_type=fsobject, stem=stem)
     a_file.write_text("".join(random.choices(string.printable, k=FILE_LENGTH)))
     return [a_file]
@@ -287,8 +290,11 @@ def fsobject_generate_sample_data(
 
 @FileSet.generate_sample_data.register
 def file_generate_sample_data(
-    file: File, dest_dir: Path, seed: int, stem: ty.Optional[str]
-) -> ty.List[Path]:
+    file: File,
+    dest_dir: Path,
+    seed: ty.Union[int, Random] = 0,
+    stem: ty.Optional[str] = None,
+) -> ty.Iterable[Path]:
     fname = gen_filename(seed, file_type=file, stem=stem)
     stem = fname[: -len(file.strext)]
     a_file = dest_dir / fname
@@ -321,8 +327,11 @@ def file_generate_sample_data(
 
 @FileSet.generate_sample_data.register
 def directory_generate_sample_data(
-    directory: Directory, dest_dir: Path, seed: int, stem: ty.Optional[str]
-) -> ty.List[Path]:
+    directory: Directory,
+    dest_dir: Path,
+    seed: ty.Union[int, Random] = 0,
+    stem: ty.Optional[str] = None,
+) -> ty.Iterable[Path]:
     rng = Random(str(seed) + directory.mime_like)
     a_dir = dest_dir / gen_filename(rng, stem=stem)
     a_dir.mkdir()
@@ -332,8 +341,11 @@ def directory_generate_sample_data(
 
 @FileSet.generate_sample_data.register
 def directory_containing_generate_sample_data(
-    directory: DirectoryContaining, dest_dir: Path, seed: int, stem: ty.Optional[str]
-) -> ty.List[Path]:
+    directory: DirectoryContaining,
+    dest_dir: Path,
+    seed: ty.Union[int, Random] = 0,
+    stem: ty.Optional[str] = None,
+) -> ty.Iterable[Path]:
     rng = Random(str(seed) + directory.mime_like)
     a_dir = dest_dir / gen_filename(rng, stem=stem)
     a_dir.mkdir()
@@ -344,8 +356,11 @@ def directory_containing_generate_sample_data(
 
 @FileSet.generate_sample_data.register
 def set_of_sample_data(
-    set_of: SetOf, dest_dir: Path, seed: int, stem: ty.Optional[str]
-) -> ty.List[Path]:
+    set_of: SetOf,
+    dest_dir: Path,
+    seed: ty.Union[int, Random] = 0,
+    stem: ty.Optional[str] = None,
+) -> ty.Iterable[Path]:
     rng = Random(str(seed) + set_of.mime_like)
     return list(
         itertools.chain(
